@@ -1,5 +1,6 @@
 import os
 import shutil
+from typing import Dict, List
 
 import pytest
 import six
@@ -14,42 +15,42 @@ from numdoclint.helper import (DOC_PARAM_INFO_KEY_ARG_NAME,
                                DOC_RETURN_INFO_KEY_NAME,
                                DOC_RETURN_INFO_KEY_TYPE_NAME)
 
-TMP_TEST_MODULE_DIR = './tests/tmp/'
-TMP_TEST_MODULE_PATH = os.path.join(
+TMP_TEST_MODULE_DIR: str = './tests/tmp/'
+TMP_TEST_MODULE_PATH: str = os.path.join(
     TMP_TEST_MODULE_DIR, 'tmp.py')
 
 
-def setup():
+def setup() -> None:
     """Function to be executed at the start of the test.
     """
     shutil.rmtree(TMP_TEST_MODULE_DIR, ignore_errors=True)
     os.makedirs(TMP_TEST_MODULE_DIR)
-    init_file_path = os.path.join(TMP_TEST_MODULE_DIR, '__init__.py')
+    init_file_path: str = os.path.join(TMP_TEST_MODULE_DIR, '__init__.py')
     with open(init_file_path, 'w') as f:
         f.write('\n')
 
 
-def teardown():
+def teardown() -> None:
     """Function to be executed at the end of the test.
     """
     shutil.rmtree(TMP_TEST_MODULE_DIR, ignore_errors=True)
 
 
-def test__check_module_exists():
+def test__check_module_exists() -> None:
     py_module._check_module_exists(
         py_module_path='./tests/test_py_module.py')
-    with pytest.raises(IOError):
+    with pytest.raises(IOError):  # type: ignore
         py_module._check_module_exists(
             py_module_path='test_not_exists_file.py')
 
 
-def test__make_info_dict():
-    info_dict = py_module._make_info_dict(
+def test__make_info_dict() -> None:
+    info_dict: dict = py_module._make_info_dict(
         module_path='sample/path/to/module.py',
         func_name='sample_func',
         info_id=3,
         info='Sample information.')
-    schema = Schema(
+    schema: Schema = Schema(
         schema={
             py_module.INFO_KEY_MODULE_PATH:
             'sample/path/to/module.py',
@@ -61,11 +62,11 @@ def test__make_info_dict():
     schema(info_dict)
 
 
-def test__check_lacked_param():
-    expected_module_path = 'test/module/path.py'
-    expected_func_name = 'test_func_name'
-    arg_name_list = ['name', 'location_id']
-    param_info_list = [{
+def test__check_lacked_param() -> None:
+    expected_module_path: str = 'test/module/path.py'
+    expected_func_name: str = 'test_func_name'
+    arg_name_list: List[str] = ['name', 'location_id']
+    param_info_list: List[dict] = [{
         DOC_PARAM_INFO_KEY_ARG_NAME: 'name',
         DOC_PARAM_INFO_KEY_TYPE_NAME: 'str',
         DOC_PARAM_INFO_KEY_DEFAULT_VAL: '',
@@ -76,14 +77,14 @@ def test__check_lacked_param():
         DOC_PARAM_INFO_KEY_DEFAULT_VAL: '',
         DOC_PARAM_INFO_KEY_DESCRIPTION: 'Sample price.',
     }]
-    info_list = py_module._check_lacked_param(
+    info_list: List[dict] = py_module._check_lacked_param(
         module_path=expected_module_path,
         func_name=expected_func_name,
         arg_name_list=arg_name_list,
         param_info_list=param_info_list,
         kwargs_exists=False)
     assert len(info_list) == 2
-    schema_1 = Schema(
+    schema_1: Schema = Schema(
         schema={
             py_module.INFO_KEY_MODULE_PATH: expected_module_path,
             py_module.INFO_KEY_FUNC_NAME: expected_func_name,
@@ -92,7 +93,7 @@ def test__check_lacked_param():
             py_module.INFO_KEY_INFO: Any(*six.string_types),
         }, required=True)
     schema_1(info_list[0])
-    schema_2 = Schema(
+    schema_2: Schema = Schema(
         schema={
             py_module.INFO_KEY_MODULE_PATH: expected_module_path,
             py_module.INFO_KEY_FUNC_NAME: expected_func_name,
@@ -103,7 +104,7 @@ def test__check_lacked_param():
         required=True)
     schema_2(info_list[1])
 
-    arg_name_list = ['name']
+    arg_name_list: List[str] = ['name']
     info_list = py_module._check_lacked_param(
         module_path=expected_module_path,
         func_name=expected_func_name,
@@ -137,10 +138,10 @@ def test__check_lacked_param():
     assert info_list == []
 
 
-def test__check_lacked_docstring_param_type():
-    expected_module_path = 'test/path/to/module.py'
-    expected_func_name = 'test_func'
-    param_info_list = [{
+def test__check_lacked_docstring_param_type() -> None:
+    expected_module_path: str = 'test/path/to/module.py'
+    expected_func_name: str = 'test_func'
+    param_info_list: List[dict] = [{
         DOC_PARAM_INFO_KEY_ARG_NAME: 'price',
         DOC_PARAM_INFO_KEY_TYPE_NAME: '',
         DOC_PARAM_INFO_KEY_DEFAULT_VAL: '',
@@ -151,12 +152,12 @@ def test__check_lacked_docstring_param_type():
         DOC_PARAM_INFO_KEY_DEFAULT_VAL: '',
         DOC_PARAM_INFO_KEY_DESCRIPTION: 'Sample name.',
     }]
-    info_list = py_module._check_lacked_docstring_param_type(
+    info_list: List[dict] = py_module._check_lacked_docstring_param_type(
         module_path=expected_module_path,
         func_name=expected_func_name,
         param_info_list=param_info_list)
     assert len(info_list) == 1
-    schema = Schema(
+    schema: Schema = Schema(
         schema={
             py_module.INFO_KEY_MODULE_PATH: expected_module_path,
             py_module.INFO_KEY_FUNC_NAME: expected_func_name,
@@ -184,11 +185,11 @@ def test__check_lacked_docstring_param_type():
         param_info_list=param_info_list)
 
 
-def test__check_docstring_param_order():
-    expected_module_path = 'test/module/path.py'
-    expected_func_name = 'test_func_name'
-    arg_name_list = ['price', 'name']
-    param_info_list = [{
+def test__check_docstring_param_order() -> None:
+    expected_module_path: str = 'test/module/path.py'
+    expected_func_name: str = 'test_func_name'
+    arg_name_list: List[str] = ['price', 'name']
+    param_info_list: List[dict] = [{
         DOC_PARAM_INFO_KEY_ARG_NAME: 'price',
         DOC_PARAM_INFO_KEY_TYPE_NAME: 'int',
         DOC_PARAM_INFO_KEY_DEFAULT_VAL: '',
@@ -200,7 +201,7 @@ def test__check_docstring_param_order():
         DOC_PARAM_INFO_KEY_DESCRIPTION: 'Sample name.',
     }]
 
-    info_list = py_module._check_docstring_param_order(
+    info_list: List[dict] = py_module._check_docstring_param_order(
         module_path=expected_module_path,
         func_name=expected_func_name,
         arg_name_list=arg_name_list[:1],
@@ -221,7 +222,7 @@ def test__check_docstring_param_order():
         arg_name_list=arg_name_list,
         param_info_list=param_info_list)
     assert len(info_list) == 1
-    schema = Schema(
+    schema: Schema = Schema(
         schema={
             py_module.INFO_KEY_MODULE_PATH: expected_module_path,
             py_module.INFO_KEY_FUNC_NAME: expected_func_name,
@@ -233,10 +234,10 @@ def test__check_docstring_param_order():
     schema(info_list[0])
 
 
-def test__check_func_description():
-    expected_module_path = 'sample/module/path.py'
-    expected_func_name = 'sample_func'
-    docstring = """
+def test__check_func_description() -> None:
+    expected_module_path: str = 'sample/module/path.py'
+    expected_func_name: str = 'sample_func'
+    docstring: str = """
     Sample docstring.
 
     Parameters
@@ -244,7 +245,7 @@ def test__check_func_description():
     price : int
         Sample price.
     """
-    info_list = py_module._check_func_description(
+    info_list: List[dict] = py_module._check_func_description(
         module_path=expected_module_path,
         func_name='test_func',
         docstring=docstring)
@@ -267,7 +268,7 @@ def test__check_func_description():
         func_name=expected_func_name,
         docstring=docstring)
     assert len(info_list) == 1
-    schema = Schema(
+    schema: Schema = Schema(
         schema={
             py_module.INFO_KEY_MODULE_PATH: expected_module_path,
             py_module.INFO_KEY_FUNC_NAME: expected_func_name,
@@ -279,11 +280,11 @@ def test__check_func_description():
     schema(info_list[0])
 
 
-def test__check_lacked_default_value():
-    expected_module_path = 'sample/module/path.py'
-    expected_func_name = 'sample_func'
+def test__check_lacked_default_value() -> None:
+    expected_module_path: str = 'sample/module/path.py'
+    expected_func_name: str = 'sample_func'
 
-    param_info_list = [{
+    param_info_list: List[dict] = [{
         DOC_PARAM_INFO_KEY_ARG_NAME: 'price',
         DOC_PARAM_INFO_KEY_TYPE_NAME: 'int',
         DOC_PARAM_INFO_KEY_DEFAULT_VAL: '',
@@ -304,19 +305,19 @@ def test__check_lacked_default_value():
         DOC_PARAM_INFO_KEY_DEFAULT_VAL: '5',
         DOC_PARAM_INFO_KEY_DESCRIPTION: 'Sample tax value.',
     }]
-    default_val_info_dict = {
+    default_val_info_dict: Dict[str, str] = {
         'price': '200',
         'location_id': '',
         'tax': '5',
     }
-    info_list = py_module._check_lacked_default_value(
+    info_list: List[dict] = py_module._check_lacked_default_value(
         module_path=expected_module_path,
         func_name=expected_func_name,
         param_info_list=param_info_list,
         default_val_info_dict=default_val_info_dict,
         optional_arg_name_list=[])
     assert len(info_list) == 2
-    schema_1 = Schema(
+    schema_1: Schema = Schema(
         schema={
             py_module.INFO_KEY_MODULE_PATH: expected_module_path,
             py_module.INFO_KEY_FUNC_NAME: expected_func_name,
@@ -326,7 +327,7 @@ def test__check_lacked_default_value():
         },
         required=True)
     schema_1(info_list[0])
-    schema_2 = Schema(
+    schema_2: Schema = Schema(
         schema={
             py_module.INFO_KEY_MODULE_PATH: expected_module_path,
             py_module.INFO_KEY_FUNC_NAME: expected_func_name,
@@ -346,17 +347,17 @@ def test__check_lacked_default_value():
     assert len(info_list) == 1
 
 
-def test__check_lacked_return():
-    expected_module_path = 'sample/module/path.py'
-    expected_func_name = 'sample_func'
-    info_list = py_module._check_lacked_return(
+def test__check_lacked_return() -> None:
+    expected_module_path: str = 'sample/module/path.py'
+    expected_func_name: str = 'sample_func'
+    info_list: List[dict] = py_module._check_lacked_return(
         module_path=expected_module_path,
         func_name=expected_func_name,
         return_val_info_list=[],
         return_val_exists_in_func=False)
     assert info_list == []
 
-    return_val_info_list = [{
+    return_val_info_list: List[Dict[str, str]] = [{
         DOC_RETURN_INFO_KEY_NAME: 'price',
         DOC_RETURN_INFO_KEY_TYPE_NAME: 'int',
         DOC_RETURN_INFO_KEY_DESCRIPTION: 'Sample price.',
@@ -378,7 +379,7 @@ def test__check_lacked_return():
         return_val_info_list=[],
         return_val_exists_in_func=True)
     assert len(info_list) == 1
-    schema = Schema(
+    schema: Schema = Schema(
         schema={
             py_module.INFO_KEY_MODULE_PATH: expected_module_path,
             py_module.INFO_KEY_FUNC_NAME: expected_func_name,
@@ -407,17 +408,17 @@ def test__check_lacked_return():
     schema(info_list[0])
 
 
-def test__check_lacked_return_docstring_type():
-    expected_module_path = 'sample/module/path.py'
-    expected_func_name = 'sample_func'
+def test__check_lacked_return_docstring_type() -> None:
+    expected_module_path: str = 'sample/module/path.py'
+    expected_func_name: str = 'sample_func'
 
-    info_list = py_module._check_lacked_return_docstring_type(
+    info_list: List[dict] = py_module._check_lacked_return_docstring_type(
         module_path=expected_module_path,
         func_name=expected_func_name,
         return_val_info_list=[])
     assert info_list == []
 
-    return_val_info_list = [{
+    return_val_info_list: List[Dict[str, str]] = [{
         DOC_RETURN_INFO_KEY_NAME: 'price',
         DOC_RETURN_INFO_KEY_TYPE_NAME: '',
         DOC_RETURN_INFO_KEY_DESCRIPTION: 'Sample price.',
@@ -435,7 +436,7 @@ def test__check_lacked_return_docstring_type():
         func_name=expected_func_name,
         return_val_info_list=return_val_info_list)
     assert len(info_list) == 2
-    schema = Schema(
+    schema: Schema = Schema(
         schema={
             py_module.INFO_KEY_MODULE_PATH: expected_module_path,
             py_module.INFO_KEY_FUNC_NAME: expected_func_name,
@@ -450,17 +451,18 @@ def test__check_lacked_return_docstring_type():
     assert 'name' in info_list[1][py_module.INFO_KEY_INFO]
 
 
-def test__check_lacked_docstring_param_description():
-    expected_module_path = 'sample/module/path.py'
-    expected_func_name = 'sample_func'
+def test__check_lacked_docstring_param_description() -> None:
+    expected_module_path: str = 'sample/module/path.py'
+    expected_func_name: str = 'sample_func'
 
-    info_list = py_module._check_lacked_docstring_param_description(
-        module_path=expected_module_path,
-        func_name=expected_func_name,
-        param_info_list=[])
+    info_list: List[dict] = \
+        py_module._check_lacked_docstring_param_description(
+            module_path=expected_module_path,
+            func_name=expected_func_name,
+            param_info_list=[])
     assert info_list == []
 
-    param_info_list = [{
+    param_info_list: List[Dict[str, str]] = [{
         DOC_PARAM_INFO_KEY_ARG_NAME: 'price',
         DOC_PARAM_INFO_KEY_TYPE_NAME: 'int',
         DOC_PARAM_INFO_KEY_DEFAULT_VAL: '',
@@ -476,12 +478,13 @@ def test__check_lacked_docstring_param_description():
         DOC_PARAM_INFO_KEY_DEFAULT_VAL: '',
         DOC_PARAM_INFO_KEY_DESCRIPTION: 'Sample location id.',
     }]
-    info_list = py_module._check_lacked_docstring_param_description(
-        module_path=expected_module_path,
-        func_name=expected_func_name,
-        param_info_list=param_info_list)
+    info_list: List[dict] = \
+        py_module._check_lacked_docstring_param_description(
+            module_path=expected_module_path,
+            func_name=expected_func_name,
+            param_info_list=param_info_list)
     assert len(info_list) == 2
-    schema = Schema(
+    schema: Schema = Schema(
         schema={
             py_module.INFO_KEY_MODULE_PATH: expected_module_path,
             py_module.INFO_KEY_FUNC_NAME: expected_func_name,
@@ -497,16 +500,17 @@ def test__check_lacked_docstring_param_description():
 
 
 def test__check_lacked_return_docstring_description():
-    expected_module_path = 'sample/module/path.py'
-    expected_func_name = 'sample_func'
+    expected_module_path: str = 'sample/module/path.py'
+    expected_func_name: str = 'sample_func'
 
-    info_list = py_module._check_lacked_return_docstring_description(
-        module_path=expected_module_path,
-        func_name=expected_func_name,
-        return_val_info_list=[])
+    info_list: List[dict] = \
+        py_module._check_lacked_return_docstring_description(
+            module_path=expected_module_path,
+            func_name=expected_func_name,
+            return_val_info_list=[])
     assert info_list == []
 
-    return_val_info_list = [{
+    return_val_info_list: List[Dict[str, str]] = [{
         DOC_RETURN_INFO_KEY_NAME: 'price',
         DOC_RETURN_INFO_KEY_TYPE_NAME: 'int',
         DOC_RETURN_INFO_KEY_DESCRIPTION: '',
@@ -524,7 +528,7 @@ def test__check_lacked_return_docstring_description():
         func_name=expected_func_name,
         return_val_info_list=return_val_info_list)
     assert len(info_list) == 2
-    schema = Schema(
+    schema: Schema = Schema(
         schema={
             py_module.INFO_KEY_MODULE_PATH: expected_module_path,
             py_module.INFO_KEY_FUNC_NAME: expected_func_name,
@@ -539,7 +543,7 @@ def test__check_lacked_return_docstring_description():
     assert 'name' in info_list[1][py_module.INFO_KEY_INFO]
 
 
-def _check_info_list_schema(info_list):
+def _check_info_list_schema(info_list: List[dict]) -> None:
     """
     Check the list schema of lint result information.
 
@@ -553,7 +557,7 @@ def _check_info_list_schema(info_list):
     MultipleInvalid
         If the schema is invalid.
     """
-    schema = Schema(
+    schema: Schema = Schema(
         schema={
             py_module.INFO_KEY_MODULE_PATH: Any(*six.string_types),
             py_module.INFO_KEY_FUNC_NAME: Any(*six.string_types),
@@ -565,7 +569,8 @@ def _check_info_list_schema(info_list):
         schema(info_dict)
 
 
-def _check_info_id_is_in_list(expected_info_id, info_list):
+def _check_info_id_is_in_list(
+        expected_info_id: int, info_list: List[dict]) -> None:
     """
     Check that the target info id is included in the list.
 
@@ -581,15 +586,16 @@ def _check_info_id_is_in_list(expected_info_id, info_list):
     AssertionError
         If the target id is not included in the list.
     """
-    id_list = [info_dict[py_module.INFO_KEY_INFO_ID]
-               for info_dict in info_list]
-    is_in = expected_info_id in id_list
+    id_list: List[int] = [
+        info_dict[py_module.INFO_KEY_INFO_ID]
+        for info_dict in info_list]
+    is_in: bool = expected_info_id in id_list
     assert is_in
 
 
-def test_get_single_func_info_list():
+def test_get_single_func_info_list() -> None:
 
-    module_str = '''
+    module_str: str = '''
 import os
 import sys
 
@@ -770,9 +776,9 @@ def sample_func_15(price):
 '''
 
     def _exec_target_func(
-            func_name, enable_default_or_optional_doc_check=True,
-            skip_decorator_name_list=['Appender'],
-            ignore_info_id_list=[]):
+            func_name: str, enable_default_or_optional_doc_check: bool = True,
+            skip_decorator_name_list: List[str] = ['Appender'],
+            ignore_info_id_list: List[int] = []) -> List[dict]:
         """
         Execute the function to be tested and get the return value.
 
@@ -795,8 +801,8 @@ def sample_func_15(price):
         info_list : list of dicts
             Return value after function execution.
         """
-        enable_def_or_opt_check = enable_default_or_optional_doc_check
-        info_list = py_module.get_single_func_info_list(
+        enable_def_or_opt_check: bool = enable_default_or_optional_doc_check
+        info_list: List[dict] = py_module.get_single_func_info_list(
             path=TMP_TEST_MODULE_PATH,
             code_str=module_str,
             func_name=func_name,
@@ -808,7 +814,7 @@ def sample_func_15(price):
     with open(TMP_TEST_MODULE_PATH, 'w') as f:
         f.write(module_str)
 
-    info_list = _exec_target_func(func_name='sample_func_1')
+    info_list: List[dict] = _exec_target_func(func_name='sample_func_1')
     _check_info_list_schema(info_list=info_list)
     _check_info_id_is_in_list(
         expected_info_id=py_module.INFO_ID_LACKED_FUNC_DESCRIPTION,
@@ -906,15 +912,15 @@ def sample_func_15(price):
     assert len(info_list) == 0
 
 
-def test_check_python_module():
-    module_str = """
+def test_check_python_module() -> None:
+    module_str: str = """
 price = 100
 name = 'apple'
 location_id = 10
 """
     with open(TMP_TEST_MODULE_PATH, 'w') as f:
         f.write(module_str)
-    info_list = py_module.check_python_module(
+    info_list: List[dict] = py_module.check_python_module(
         py_module_path=TMP_TEST_MODULE_PATH,
         enable_default_or_optional_doc_check=True)
     assert info_list == []
@@ -1022,15 +1028,15 @@ def sample_func(price):
     assert len(info_list) != 0
 
 
-def test_check_python_module_recursively():
-    child_dir_path = os.path.join(TMP_TEST_MODULE_DIR, 'child_dir/')
+def test_check_python_module_recursively() -> None:
+    child_dir_path: str = os.path.join(TMP_TEST_MODULE_DIR, 'child_dir/')
     if not os.path.exists(child_dir_path):
         os.makedirs(child_dir_path)
-    child_dir_init_path = os.path.join(child_dir_path, '__init__.py')
+    child_dir_init_path: str = os.path.join(child_dir_path, '__init__.py')
     with open(child_dir_init_path, 'w') as f:
         f.write('\n')
 
-    module_str_1 = '''
+    module_str_1: str = '''
 def sample_func_1(name):
     """
     Sample function.
@@ -1045,7 +1051,7 @@ def sample_func_1(name):
     with open(TMP_TEST_MODULE_PATH, 'w') as f:
         f.write(module_str_1)
 
-    module_str_2 = '''
+    module_str_2: str = '''
 import os
 import sys
 
@@ -1067,7 +1073,7 @@ def sample_func_2(price=100, name='apple'):
     with open(module_path_2, 'w') as f:
         f.write(module_str_2)
 
-    module_str_3 = '''
+    module_str_3: str = '''
 import os
 import sys
 
@@ -1078,11 +1084,11 @@ y = 200
     with open(module_path_3, 'w') as f:
         f.write(module_str_3)
 
-    info_list = py_module.check_python_module_recursively(
+    info_list: List[dict] = py_module.check_python_module_recursively(
         dir_path=TMP_TEST_MODULE_DIR,
         enable_default_or_optional_doc_check=True)
     _check_info_list_schema(info_list=info_list)
-    module_path_list = [
+    module_path_list: List[str] = [
         info_dict[py_module.INFO_KEY_MODULE_PATH]
         for info_dict in info_list]
     assert TMP_TEST_MODULE_PATH in module_path_list
@@ -1103,7 +1109,7 @@ y = 200
         enable_default_or_optional_doc_check=True)
     assert not info_list
 
-    module_str_4 = '''
+    module_str_4: str = '''
 def sample_func_3(price=100):
     """
     Sample function.
@@ -1115,7 +1121,7 @@ def sample_func_3(price=100):
     """
     pass
     '''
-    module_path_4 = os.path.join(child_dir_path, 'test_module_4.py')
+    module_path_4: str = os.path.join(child_dir_path, 'test_module_4.py')
     with open(module_path_4, 'w') as f:
         f.write(module_str_4)
     info_list = py_module.check_python_module_recursively(
@@ -1127,12 +1133,12 @@ def sample_func_3(price=100):
         for info_dict in info_list]
     assert module_path_4 not in module_path_list
 
-    module_str_5 = '''
+    module_str_5: str = '''
 @Appender
 def sample_func_4(price):
     pass
     '''
-    module_path_5 = os.path.join(child_dir_path, 'test_module_5.py')
+    module_path_5: str = os.path.join(child_dir_path, 'test_module_5.py')
     with open(module_path_5, 'w') as f:
         f.write(module_str_5)
     info_list = py_module.check_python_module_recursively(
@@ -1149,8 +1155,8 @@ def sample_func_4(price):
     assert module_path_5 in module_path_list
 
 
-def test__print_info_list():
-    info_list = [{
+def test__print_info_list() -> None:
+    info_list: List[dict] = [{
         py_module.INFO_KEY_MODULE_PATH: 'sample/module/path_1.py',
         py_module.INFO_KEY_FUNC_NAME: 'sample_func_1',
         py_module.INFO_KEY_INFO_ID: 1,
@@ -1161,7 +1167,7 @@ def test__print_info_list():
         py_module.INFO_KEY_INFO_ID: 2,
         py_module.INFO_KEY_INFO: 'Sample information 2.',
     }]
-    printed_str = py_module._print_info_list(
+    printed_str: str = py_module._print_info_list(
         info_list=info_list,
         verbose=0)
     assert printed_str == ''
@@ -1170,17 +1176,17 @@ def test__print_info_list():
         info_list=info_list, verbose=1)
     assert printed_str != ''
     for info_dict in info_list:
-        module_path = info_dict[py_module.INFO_KEY_MODULE_PATH]
-        func_name = info_dict[py_module.INFO_KEY_FUNC_NAME]
-        info = info_dict[py_module.INFO_KEY_INFO]
+        module_path: str = info_dict[py_module.INFO_KEY_MODULE_PATH]
+        func_name: str = info_dict[py_module.INFO_KEY_FUNC_NAME]
+        info: str = info_dict[py_module.INFO_KEY_INFO]
         assert module_path in printed_str
         assert func_name in printed_str
         assert info in printed_str
 
 
-def test_is_func_name_to_ignore():
-    ignore_func_name_prefix_list = ['test_', 'sample_']
-    result_bool = py_module.is_func_name_to_ignore(
+def test_is_func_name_to_ignore() -> None:
+    ignore_func_name_prefix_list: List[str] = ['test_', 'sample_']
+    result_bool: bool = py_module.is_func_name_to_ignore(
         func_name='test_get_name',
         ignore_func_name_prefix_list=ignore_func_name_prefix_list)
     assert result_bool
@@ -1196,8 +1202,8 @@ def test_is_func_name_to_ignore():
     assert not result_bool
 
 
-def test__remove_info_to_ignore_by_id():
-    info_list = py_module._remove_info_to_ignore_by_id(
+def test__remove_info_to_ignore_by_id() -> None:
+    info_list: List[dict] = py_module._remove_info_to_ignore_by_id(
         info_list=[],
         ignore_info_id_list=[])
     assert info_list == []
@@ -1222,8 +1228,8 @@ def test__remove_info_to_ignore_by_id():
         == py_module.INFO_ID_LACKED_ARGUMENT)
 
 
-def test_get_info_id_list():
-    info_id_list = py_module.get_info_id_list()
+def test_get_info_id_list() -> None:
+    info_id_list: List[int] = py_module.get_info_id_list()
     assert info_id_list
     for info_id in info_id_list:
         assert isinstance(info_id, int)
